@@ -1,12 +1,20 @@
 import string
+import warnings
 
 import numpy as np
 import pytest
 from torch import nn
 
-from pytorch_widedeep.models import Wide, TabMlp, WideDeep, TabTransformer
+from pytorch_widedeep.models import (
+    Wide,
+    TabMlp,
+    TabNet,
+    WideDeep,
+    TabTransformer,
+)
 from pytorch_widedeep.metrics import R2Score
 from pytorch_widedeep.training import Trainer
+from pytorch_widedeep.dataloaders import DataLoaderImbalanced
 
 # Wide array
 X_wide = np.random.choice(50, (32, 10))
@@ -23,6 +31,7 @@ X_tab = np.vstack(embed_cols + cont_cols).transpose()
 # Target
 target_regres = np.random.random(32)
 target_binary = np.random.choice(2, 32)
+target_binary_imbalanced = np.random.choice(2, 32, p=[0.75, 0.25])
 target_multic = np.random.choice(3, 32)
 
 # Test dictionary
@@ -138,6 +147,51 @@ def test_fit_objectives_tab_transformer(
     assert preds.shape[0] == 32, probs.shape[1] == probs_dim
 
 
+##############################################################################
+# Repeat 1st set of tests with TabNet
+##############################################################################
+
+
+@pytest.mark.parametrize(
+    "X_wide, X_tab, target, objective, X_wide_test, X_tab_test, X_test, pred_dim, probs_dim",
+    [
+        (X_wide, X_tab, target_regres, "regression", X_wide, X_tab, None, 1, None),
+        (X_wide, X_tab, target_binary, "binary", X_wide, X_tab, None, 1, 2),
+        (X_wide, X_tab, target_multic, "multiclass", X_wide, X_tab, None, 3, 3),
+        (X_wide, X_tab, target_regres, "regression", None, None, X_test, 1, None),
+        (X_wide, X_tab, target_binary, "binary", None, None, X_test, 1, 2),
+        (X_wide, X_tab, target_multic, "multiclass", None, None, X_test, 3, 3),
+    ],
+)
+def test_fit_objectives_tabnet(
+    X_wide,
+    X_tab,
+    target,
+    objective,
+    X_wide_test,
+    X_tab_test,
+    X_test,
+    pred_dim,
+    probs_dim,
+):
+    warnings.filterwarnings("ignore")
+    wide = Wide(np.unique(X_wide).shape[0], pred_dim)
+    tab_transformer = TabNet(
+        column_idx={k: v for v, k in enumerate(colnames)},
+        embed_input=embed_input,
+        continuous_cols=colnames[5:],
+    )
+    model = WideDeep(wide=wide, deeptabular=tab_transformer, pred_dim=pred_dim)
+    trainer = Trainer(model, objective=objective, verbose=0)
+    trainer.fit(X_wide=X_wide, X_tab=X_tab, target=target, batch_size=16)
+    preds = trainer.predict(X_wide=X_wide, X_tab=X_tab, X_test=X_test)
+    if objective == "binary":
+        pass
+    else:
+        probs = trainer.predict_proba(X_wide=X_wide, X_tab=X_tab, X_test=X_test)
+    assert preds.shape[0] == 32, probs.shape[1] == probs_dim
+
+
 ##############################################################################
 # Test fit with R2 for regression
 ##############################################################################
@@ -182,3 +236,30 @@ def test_aliases():
         and trainer.__wd_aliases_used["objective"] == "loss"
         and trainer.__wd_aliases_used["finetune"] == "warmup"
     )
+
+
+##############################################################################
+# Test custom dataloader
+##############################################################################
+
+
+def test_custom_dataloader():
+    wide = Wide(np.unique(X_wide).shape[0], 1)
+    deeptabular = TabMlp(
+        mlp_hidden_dims=[32, 16],
+        mlp_dropout=[0.5, 0.5],
+        column_idx=column_idx,
+        embed_input=embed_input,
+        continuous_cols=colnames[-5:],
+    )
+    model = WideDeep(wide=wide, deeptabular=deeptabular)
+    trainer = Trainer(model, loss="binary", verbose=0)
+    trainer.fit(
+        X_wide=X_wide,
+        X_tab=X_tab,
+        target=target_binary_imbalanced,
+        batch_size=16,
+        custom_dataloader=DataLoaderImbalanced,
+    )
+    # simply checking that runs with DataLoaderImbalanced
+    assert "train_loss" in trainer.history.keys()
